==> apache-ranger-0.6.3.tar.gz: apache-ranger-0.6.3/unixauthclient/src/main/java/org/apache/ranger/authentication/unix/jaas/PamPrincipal.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ranger.authentication.unix.jaas;

import org.jvnet.libpam.UnixUser;

import java.security.Principal;
import java.util.Collections;
import java.util.Set;


public class PamPrincipal extends Object implements Principal {
    private String _userName;
    private String _gecos;
    private String _homeDir;
    private String _shell;
    private int _uid;
    private int _gid;
    private Set<String> _groups;

    public PamPrincipal(UnixUser user)
    {
        super();
        _userName = user.getUserName();
        _gecos = user.getGecos();
        _homeDir = user.getDir();
        _shell = user.getShell();
        _uid = user.getUID();
        _gid = user.getGID();
        _groups = Collections.unmodifiableSet(user.getGroups());
    }

    @Override
    public String getName()
    {
        return _userName;
    }

    public String getGecos()
    {
        return _gecos;
    }

    public String getHomeDir()
    {
        return _homeDir;
    }

    public String getShell()
    {
        return _shell;
    }

    public int getUid()
    {
        return _uid;
    }

    public int getGid()
    {
        return _gid;
    }

    public Set<String> getGroups()
    {
        return _groups;
    }

}

==> apache-ranger-1.1.0.tar.gz: apache-ranger-1.1.0/unixauthclient/src/main/java/org/apache/ranger/authentication/unix/jaas/PamPrincipal.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ranger.authentication.unix.jaas;

import org.jvnet.libpam.UnixUser;

import java.security.Principal;
import java.util.Collections;
import java.util.Set;


public class PamPrincipal implements Principal {
    private String _userName;
    private String _gecos;
    private String _homeDir;
    private String _shell;
    private int _uid;
    private int _gid;
    private Set<String> _groups;

    public PamPrincipal(UnixUser user)
    {
        super();
        _userName = user.getUserName();
        _gecos = user.getGecos();
        _homeDir = user.getDir();
        _shell = user.getShell();
        _uid = user.getUID();
        _gid = user.getGID();
        _groups = Collections.unmodifiableSet(user.getGroups());
    }

    @Override
    public String getName()
    {
        return _userName;
    }

    public String getGecos()
    {
        return _gecos;
    }

    public String getHomeDir()
    {
        return _homeDir;
    }

    public String getShell()
    {
        return _shell;
    }

    public int getUid()
    {
        return _uid;
    }

    public int getGid()
    {
        return _gid;
    }

    public Set<String> getGroups()
    {
        return _groups;
    }

}
